import React from 'react';
import clsx from 'clsx';
import ListItem from '@material-ui/core/ListItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';
import ShowChartIcon from '@material-ui/icons/ShowChart';
import WbSunnyIcon from '@material-ui/icons/WbSunny';
import WavesIcon from '@material-ui/icons/Waves';
import AcUnitIcon from '@material-ui/icons/AcUnit';
import { NavLink as RouterNavLink, useLocation } from 'react-router-dom';
import { makeStyles } from '@material-ui/core/styles';
import { useType } from '../utils/helpers';

const useStyles = makeStyles((theme) => ({
  link: {
    textDecoration: 'none',
    color: theme.palette.text.primary,
    '&:hover': {
      textDecoration: 'none',
    },
  },
}));

const Navigation = () => {
  const styles = useStyles();
  const { pathname } = useLocation();

  const type = useType();
  return (
    <div>
      <RouterNavLink to="/home-page" className={clsx(styles.link)}>
        <ListItem button selected={pathname === '/home-page' && !type ? 'selected' : null}>
          <ListItemIcon>
            <WbSunnyIcon />
          </ListItemIcon>
          <ListItemText primary="Sunshine" />
        </ListItem>
      </RouterNavLink>
      <RouterNavLink to="/home-page?type=air" className={clsx(styles.link)}>
        <ListItem button selected={pathname === '/home-page' && type === 'air' ? 'selected' : null}>
          <ListItemIcon>
            <WavesIcon />
          </ListItemIcon>
          <ListItemText primary="Air" />
        </ListItem>
      </RouterNavLink>
      <RouterNavLink to="/home-page?type=temp" className={clsx(styles.link)}>
        <ListItem button selected={pathname === '/home-page' && type === 'temp' ? 'selected' : null}>
          <ListItemIcon>
            <AcUnitIcon />
          </ListItemIcon>
          <ListItemText primary="Temperture" />
        </ListItem>
      </RouterNavLink>
      <RouterNavLink to="/chart" className={({ isActive }) => [clsx(styles.link), isActive ? 'selected' : null].join(' ')}>
        <ListItem button selected={pathname === '/chart'}>
          <ListItemIcon>
            <ShowChartIcon />
          </ListItemIcon>
          <ListItemText primary="Chart" />
        </ListItem>
      </RouterNavLink>
    </div>
  );
};

export default Navigation;
